Generic connection failure not covered by a more specific error type.
Summary
Functions
Create an Elixir.Quiver.Error.ConnectionFailed without raising it.
Types
@type t() :: Splode.Error.t()
Generic connection failure not covered by a more specific error type.
Create an Elixir.Quiver.Error.ConnectionFailed without raising it.
@type t() :: Splode.Error.t()