Quiver.Error.GoAway exception (quiver v0.2.0)

Copy Markdown View Source

Connection-level GOAWAY signal -- the connection is shutting down.

This is an unrecoverable error representing the GOAWAY event itself. For streams that were never processed by the server (stream ID above last_stream_id), see Quiver.Error.GoAwayUnprocessed which is transient and safe to retry on a new connection.

Summary

Functions

Create an Elixir.Quiver.Error.GoAway without raising it.

Types

t()

@type t() :: Splode.Error.t()

Functions

exception(args)

@spec exception(opts :: Keyword.t()) :: %Quiver.Error.GoAway{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  debug_data: term(),
  error_code: term(),
  last_stream_id: term(),
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Create an Elixir.Quiver.Error.GoAway without raising it.

Keys

  • :last_stream_id
  • :error_code
  • :debug_data