Quiver.Error.GoAwayUnprocessed exception (quiver v0.2.0)

Copy Markdown View Source

Request was not processed by the server before GOAWAY.

The stream ID exceeds the server's last_stream_id, meaning the server never began processing this request. Safe to retry on a new connection.

Summary

Types

t()

@type t() :: Splode.Error.t()

Functions

exception(args)

@spec exception(opts :: Keyword.t()) :: %Quiver.Error.GoAwayUnprocessed{
  __exception__: true,
  bread_crumbs: term(),
  class: term(),
  debug_data: term(),
  error_code: term(),
  last_stream_id: term(),
  path: term(),
  splode: term(),
  stacktrace: term(),
  vars: term()
}

Create an Elixir.Quiver.Error.GoAwayUnprocessed without raising it.

Keys

  • :last_stream_id
  • :error_code
  • :debug_data