TLS handshake failed due to cipher mismatch, protocol error, etc.
Summary
Functions
Create an Elixir.Quiver.Error.TLSHandshakeFailed without raising it.
Types
@type t() :: Splode.Error.t()
TLS handshake failed due to cipher mismatch, protocol error, etc.
Create an Elixir.Quiver.Error.TLSHandshakeFailed without raising it.
@type t() :: Splode.Error.t()