Stateless pool routing module.
Looks up existing pools via Registry (hot path) and creates new ones via DynamicSupervisor on first request to an origin (cold path).
Summary
Functions
Returns an existing pool for the origin, or starts one via DynamicSupervisor.
Returns pool stats for a known origin, or {:error, :not_found}.
Types
@type origin() :: {:http | :https, String.t(), :inet.port_number()}
Functions
Returns an existing pool for the origin, or starts one via DynamicSupervisor.
Returns pool stats for a known origin, or {:error, :not_found}.